@@ -1,5 +1,5 @@
 #
-# $Id: Online.pm,v 1.2 2006/12/05 20:31:17 gomor Exp $
+# $Id: Online.pm,v 1.3 2006/12/06 21:15:36 gomor Exp $
 #
 package Net::Frame::Dump::Online;
 use strict;
@@ -311,8 +311,6 @@ sub next {
 
 sub nextAll { print "XXX: Dump::nextAll: broken, next() does not return Simple objects anymore\n" }
 
-
-sub framesStore  { shift->_dumpFramesStored(@_) }
 sub getFramesFor { shift->_dumpGetFramesFor(@_) }
 sub store        { shift->_dumpStore(@_)        }
 sub flush        { shift->_dumpFlush(@_)        }
@@ -339,6 +337,30 @@ Net::Frame::Dump::Online - tcpdump like implementation, online mode
 
 =over 4
 
+=item B<new>
+
+=item B<start>
+
+=item B<stop>
+
+=item B<getFramesFor>
+
+=item B<getStats>
+
+=item B<isFather>
+
+=item B<isSon>
+
+=item B<next>
+
+=item B<nextAll>
+
+=item B<store>
+
+=item B<flush>
+
+=item B<timeoutReset>
+
 =back
 
 =head1 AUTHOR
